@@ -9,7 +9,7 @@ Created on Thu May 21 16:41:01 2020
 import functools
 import numpy as np
 
-from .. import base
+from .. import misc
 
 
 def _axial2_broadcast(func):
@@ -17,12 +17,12 @@ def _axial2_broadcast(func):
     does not change"""
     @functools.wraps(func)
     def wrapped_cum_atc(a, axis=None, **kwargs):
-        if base.istablarray(a):
+        if misc.istablarray(a):
             axis = a._viewdims[axis]
             rarray = func(a.base, axis=axis, **kwargs)
             rclass = a.__class__
             # once a TablArray, usually a TablArray
-            return base._rval_once_a_ta(rclass, rarray, a.ts.cdim, a.view)
+            return misc._rval_once_a_ta(rclass, rarray, a.ts.cdim, a.view)
         else:
             # pass through to numpy
             return func(a, axis=axis, **kwargs)
